export const BOILERPLATE_OPTIONS = {
  connector: "Connector",
  ui: "Integration UI",
  build: "Build Event Handler",
};

export const example = (boilerplate: string[]) => {
  let code = `import { NetlifyIntegration } from "@netlify/sdk";

const integration = new NetlifyIntegration();
`;

  if (boilerplate.includes(BOILERPLATE_OPTIONS.connector)) {
    code += `const connector = integration.addConnector({
  typePrefix: "Example",
});

/**
 * Define your content models here.
 * https://sdk.netlify.com/connectors/connector-apis/#model
 */
connector.model(async ({ define }) => {
  define.nodeModel({
    name: "User",
    fields: {
      name: {
        type: "String",
        required: true,
      },
      posts: {
        type: "Post",
        list: true,
      },
    },
  });

  define.nodeModel({
    name: "Post",
    fields: {
      title: {
        type: "String",
        required: true,
      },
      blocks: {
        list: true,
        required: true,
        type: define.object({
          name: "Blocks",
          fields: {
            title: {
              type: "String",
            },
            content: {
              type: "String",
            },
          },
        }),
      },
    },
  });
});

/**
 * Fetch and store data from your API here.
 * https://sdk.netlify.com/connectors/connector-apis/#createallnodes
 */
connector.event("createAllNodes", ({ models }) => {
  models.User.create({
    id: "1",
    name: "Annie",
    posts: [
      {
        id: "1",
        __typename: "Post",
      },
    ],
  });
  models.Post.create({
    id: "1",
    title: "Hello World",
    blocks: [
      {
        title: "Example block title",
        content: "You can create complex content models",
      },
    ],
  });
});

/**
 * Fetch and store changed data from your API here.
 * https://sdk.netlify.com/connectors/connector-apis/#updatenodes
 */
connector.event("updateNodes", ({ models }) => {
  models.User.create({
    id: "1", // overwrites the existing User node with this ID
    name: "Annie",
    posts: [
      {
        id: "1",
        __typename: "Post",
      },
    ],
  });
  models.Post.create({
    id: "2", // creates a new Post since this ID doesn't exist yet
    title: "Writing lots of posts these days",
    blocks: [
      {
        title: "Page section",
        content: "what up",
      },
    ],
  });
});
`;
  }

  if (
    boilerplate.includes(BOILERPLATE_OPTIONS.build) ||
    boilerplate.includes(BOILERPLATE_OPTIONS.connector)
  ) {
    code += `
integration.onEnable(async (_, { teamId, siteId, client }) => {${
      boilerplate.includes(BOILERPLATE_OPTIONS.build)
        ? `
  // Build event handlers are disabled by default, so we need to
  // enable them when the integration is enabled.

  siteId && await client.enableBuildEventHandlers(siteId);`
        : ""
    }
  ${
    boilerplate.includes(BOILERPLATE_OPTIONS.connector)
      ? `// Connectors are disabled by default, so we need to
  // enable them when the integration is enabled.
  
  teamId && await client.enableConnectors(teamId);
  `
      : ""
  }
  return {
    statusCode: 200,
  };
});
`;
  }

  if (boilerplate.includes(BOILERPLATE_OPTIONS.build)) {
    code += `
integration.addBuildEventHandler("onPreBuild", () => {
  console.log("Hello there.");
});
  `;
  }

  code += `
export { integration };

`;

  return code;
};

export const createBasicIntegrationUI = (
  friendlyName: string,
) => `import { NetlifyIntegrationUI } from "@netlify/sdk";

const integrationUI = new NetlifyIntegrationUI("${friendlyName}");

const surface = integrationUI.addSurface("integrations-settings");

const route = surface.addRoute("/");

route.addText({
    value: "Welcome to the ${friendlyName} integration UI. This is where you can create your own custom UI for your integration, which will be displayed in the Netlify UI."
});

export { integrationUI };

`;

export const GITIGNORE = `
.ntli
node_modules
.cache
dev-model.gql
`;

export const createReadme = (component: string) => `
# Netlify Integration

This integration is created using the [Netlify SDK](https://sdk.netlify.com/get-started/introduction/). It is a boilerplate for creating a new integration.

## Scripts

These are some common scripts you will use when developing your integration. If you want to know what else is possible, [check out the documentation](https://sdk.netlify.com/netlify-sdk-utility-tools-reference/).

### Build

This builds the integration into a \`.ntli\` folder. This is the folder that Netlify uses to run the integration.

\`\`\`bash
npm run build
\`\`\`
${
  component === "connector"
    ? `### Dev

This bundles your integration code and starts a local GraphQL server for any Connectors you have defined. This is useful for testing your integration locally.

\`\`\`bash
npm run dev
\`\`\`
`
    : ""
}
${
  component === "ui"
    ? `### Preview

This bundles your integration code and starts a preview server. This is useful for previewing your integration UI locally.

\`\`\`bash
npm run preview
\`\`\``
    : ""
}
### Deploy

Are you ready to deploy your integration? Check our documentation on publishing your ntegration as a [private integration](https://sdk.netlify.com/publish/private-integrations/) or [partner integration](https://sdk.netlify.com/publish/partner-integrations/).
`;
